@@ -188,7 +188,7 @@ mutation CreateNotification(
   $userId: ID
   $context: NotificationType,
   $title: String,
-  $content: Text,
+  $content: Text!,
   $link: String,
   $metadata: String,
   $linkText: String
